(function (GCN) {

	'use strict';

	/**
	 * @private
	 * @const
	 * @type {number}
	 */
	var TYPE_ID = 10008;

	/**
	 * @private
	 * @const
	 * @type {object.<string, boolean>} Default file settings.
	 */
	var DEFAULT_SETTINGS = {
		// Load file for updating
		update: true
	};

	/**
	 * @class
	 * @name FileAPI
	 * @extends ContentObjectAPI
	 * @extends TagContainerAPI
	 */
	var FileAPI = GCN.defineChainback({
		/** @lends FileAPI */

		__chainbacktype__: 'FileAPI',

		_extends: [ GCN.ContentObjectAPI, GCN.TagContainerAPI ],

		_type: 'file',

		/**
		 * @type {Array.string} Writable properties for the page object.
		 */
		WRITEABLE_PROPS: [ 'cdate',
		                    'description',
		                    'folderId', // @TODO Check if moving is implemented
							            // correctly.
		                    'name' ],

		/**
		 * Retrieve the URL of this file's binary contents. You can use this to
		 * download the file from the server or to display an image.
		 * <b>WARNING!</b> Never ever store this URL in a page for users to
		 * load an image or to provide a download link. You should always refer
		 * to published files from the backend. Referencing a file directly
		 * using this link will put heavy load on you Gentics Content.Node CMS
		 * Server.
		 *
		 * @function
		 * @name binURL
		 * @memberOf FileAPI
		 * @return {string} Source URL of this file.
		 */
		'!binURL': function () {
			return GCN.settings.BACKEND_PATH + '/rest/file/content/load/' +
				this.id() + '?sid=' + GCN.sid;
		},

		/**
		 * @see ContentObjectAPI.!_loadParams
		 */
		'!_loadParams': function () {
			return jQuery.extend(DEFAULT_SETTINGS, this._settings);
		}
	});

	GCN.file = GCN.exposeAPI(FileAPI);
	GCN.FileAPI = FileAPI;

}(GCN));
